# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtGraphsWidgets, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtGraphsWidgets`

import PySide6.QtGraphsWidgets
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtQuick
import PySide6.QtQuickWidgets
import PySide6.QtGraphs

import typing
import collections.abc
from PySide6.QtCore import Signal


class Q3DBarsWidgetItem(PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem):

    barSeriesMarginChanged   : typing.ClassVar[Signal] = ... # barSeriesMarginChanged(QSizeF)
    barSpacingChanged        : typing.ClassVar[Signal] = ... # barSpacingChanged(QSizeF)
    barSpacingRelativeChanged: typing.ClassVar[Signal] = ... # barSpacingRelativeChanged(bool)
    barThicknessChanged      : typing.ClassVar[Signal] = ... # barThicknessChanged(float)
    columnAxisChanged        : typing.ClassVar[Signal] = ... # columnAxisChanged(QCategory3DAxis*)
    floorLevelChanged        : typing.ClassVar[Signal] = ... # floorLevelChanged(float)
    multiSeriesUniformChanged: typing.ClassVar[Signal] = ... # multiSeriesUniformChanged(bool)
    primarySeriesChanged     : typing.ClassVar[Signal] = ... # primarySeriesChanged(QBar3DSeries*)
    rowAxisChanged           : typing.ClassVar[Signal] = ... # rowAxisChanged(QCategory3DAxis*)
    selectedSeriesChanged    : typing.ClassVar[Signal] = ... # selectedSeriesChanged(QBar3DSeries*)
    sliceImageChanged        : typing.ClassVar[Signal] = ... # sliceImageChanged(QImage)
    valueAxisChanged         : typing.ClassVar[Signal] = ... # valueAxisChanged(QValue3DAxis*)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, multiSeriesUniform: bool | None = ..., barThickness: float | None = ..., barSpacing: PySide6.QtCore.QSizeF | None = ..., barSpacingRelative: bool | None = ..., barSeriesMargin: PySide6.QtCore.QSizeF | None = ..., rowAxis: PySide6.QtGraphs.QCategory3DAxis | None = ..., columnAxis: PySide6.QtGraphs.QCategory3DAxis | None = ..., valueAxis: PySide6.QtGraphs.QValue3DAxis | None = ..., primarySeries: PySide6.QtGraphs.QBar3DSeries | None = ..., selectedSeries: PySide6.QtGraphs.QBar3DSeries | None = ..., floorLevel: float | None = ...) -> None: ...

    def addAxis(self, axis: PySide6.QtGraphs.QAbstract3DAxis, /) -> None: ...
    def addSeries(self, series: PySide6.QtGraphs.QBar3DSeries, /) -> None: ...
    def axes(self, /) -> typing.List[PySide6.QtGraphs.QAbstract3DAxis]: ...
    def barSeriesMargin(self, /) -> PySide6.QtCore.QSizeF: ...
    def barSpacing(self, /) -> PySide6.QtCore.QSizeF: ...
    def barThickness(self, /) -> float: ...
    def columnAxis(self, /) -> PySide6.QtGraphs.QCategory3DAxis: ...
    def event(self, event: PySide6.QtCore.QEvent, /) -> bool: ...
    def floorLevel(self, /) -> float: ...
    def insertSeries(self, index: int, series: PySide6.QtGraphs.QBar3DSeries, /) -> None: ...
    def isBarSpacingRelative(self, /) -> bool: ...
    def isMultiSeriesUniform(self, /) -> bool: ...
    def primarySeries(self, /) -> PySide6.QtGraphs.QBar3DSeries: ...
    def releaseAxis(self, axis: PySide6.QtGraphs.QAbstract3DAxis, /) -> None: ...
    def removeSeries(self, series: PySide6.QtGraphs.QBar3DSeries, /) -> None: ...
    def renderSliceToImage(self, requestedIndex: int, sliceType: PySide6.QtGraphs.QtGraphs3D.SliceCaptureType, /) -> None: ...
    def rowAxis(self, /) -> PySide6.QtGraphs.QCategory3DAxis: ...
    def selectedSeries(self, /) -> PySide6.QtGraphs.QBar3DSeries: ...
    def seriesList(self, /) -> typing.List[PySide6.QtGraphs.QBar3DSeries]: ...
    def setBarSeriesMargin(self, margin: PySide6.QtCore.QSizeF | PySide6.QtCore.QSize, /) -> None: ...
    def setBarSpacing(self, spacing: PySide6.QtCore.QSizeF | PySide6.QtCore.QSize, /) -> None: ...
    def setBarSpacingRelative(self, relative: bool, /) -> None: ...
    def setBarThickness(self, thicknessRatio: float, /) -> None: ...
    def setColumnAxis(self, axis: PySide6.QtGraphs.QCategory3DAxis, /) -> None: ...
    def setFloorLevel(self, level: float, /) -> None: ...
    def setMultiSeriesUniform(self, uniform: bool, /) -> None: ...
    def setPrimarySeries(self, series: PySide6.QtGraphs.QBar3DSeries, /) -> None: ...
    def setRowAxis(self, axis: PySide6.QtGraphs.QCategory3DAxis, /) -> None: ...
    def setValueAxis(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def valueAxis(self, /) -> PySide6.QtGraphs.QValue3DAxis: ...


class Q3DGraphsWidgetItem(PySide6.QtCore.QObject):

    activeThemeChanged       : typing.ClassVar[Signal] = ... # activeThemeChanged(QGraphsTheme*)
    ambientLightStrengthChanged: typing.ClassVar[Signal] = ... # ambientLightStrengthChanged()
    aspectRatioChanged       : typing.ClassVar[Signal] = ... # aspectRatioChanged(double)
    cameraPresetChanged      : typing.ClassVar[Signal] = ... # cameraPresetChanged(QtGraphs3D::CameraPreset)
    cameraTargetPositionChanged: typing.ClassVar[Signal] = ... # cameraTargetPositionChanged(QVector3D)
    cameraXRotationChanged   : typing.ClassVar[Signal] = ... # cameraXRotationChanged(float)
    cameraYRotationChanged   : typing.ClassVar[Signal] = ... # cameraYRotationChanged(float)
    cameraZoomLevelChanged   : typing.ClassVar[Signal] = ... # cameraZoomLevelChanged(float)
    currentFpsChanged        : typing.ClassVar[Signal] = ... # currentFpsChanged(int)
    cutoffMarginChanged      : typing.ClassVar[Signal] = ... # cutoffMarginChanged(double)
    doubleTapped             : typing.ClassVar[Signal] = ... # doubleTapped(QEventPoint,Qt::MouseButton)
    dragged                  : typing.ClassVar[Signal] = ... # dragged(QVector2D)
    gridLineTypeChanged      : typing.ClassVar[Signal] = ... # gridLineTypeChanged()
    horizontalAspectRatioChanged: typing.ClassVar[Signal] = ... # horizontalAspectRatioChanged(double)
    labelMarginChanged       : typing.ClassVar[Signal] = ... # labelMarginChanged(float)
    lightColorChanged        : typing.ClassVar[Signal] = ... # lightColorChanged()
    lightStrengthChanged     : typing.ClassVar[Signal] = ... # lightStrengthChanged()
    localeChanged            : typing.ClassVar[Signal] = ... # localeChanged(QLocale)
    longPressed              : typing.ClassVar[Signal] = ... # longPressed()
    marginChanged            : typing.ClassVar[Signal] = ... # marginChanged(double)
    maxCameraXRotationChanged: typing.ClassVar[Signal] = ... # maxCameraXRotationChanged(float)
    maxCameraYRotationChanged: typing.ClassVar[Signal] = ... # maxCameraYRotationChanged(float)
    maxCameraZoomLevelChanged: typing.ClassVar[Signal] = ... # maxCameraZoomLevelChanged(float)
    measureFpsChanged        : typing.ClassVar[Signal] = ... # measureFpsChanged(bool)
    minCameraXRotationChanged: typing.ClassVar[Signal] = ... # minCameraXRotationChanged(float)
    minCameraYRotationChanged: typing.ClassVar[Signal] = ... # minCameraYRotationChanged(float)
    minCameraZoomLevelChanged: typing.ClassVar[Signal] = ... # minCameraZoomLevelChanged(float)
    mouseMove                : typing.ClassVar[Signal] = ... # mouseMove(QPoint)
    msaaSamplesChanged       : typing.ClassVar[Signal] = ... # msaaSamplesChanged(int)
    optimizationHintChanged  : typing.ClassVar[Signal] = ... # optimizationHintChanged(QtGraphs3D::OptimizationHint)
    orthoProjectionChanged   : typing.ClassVar[Signal] = ... # orthoProjectionChanged(bool)
    pinch                    : typing.ClassVar[Signal] = ... # pinch(double)
    polarChanged             : typing.ClassVar[Signal] = ... # polarChanged(bool)
    queriedGraphPositionChanged: typing.ClassVar[Signal] = ... # queriedGraphPositionChanged(QVector3D)
    radialLabelOffsetChanged : typing.ClassVar[Signal] = ... # radialLabelOffsetChanged(float)
    rotationEnabledChanged   : typing.ClassVar[Signal] = ... # rotationEnabledChanged(bool)
    selectedElementChanged   : typing.ClassVar[Signal] = ... # selectedElementChanged(QtGraphs3D::ElementType)
    selectionEnabledChanged  : typing.ClassVar[Signal] = ... # selectionEnabledChanged(bool)
    selectionModeChanged     : typing.ClassVar[Signal] = ... # selectionModeChanged(QtGraphs3D::SelectionFlags)
    shadowQualityChanged     : typing.ClassVar[Signal] = ... # shadowQualityChanged(QtGraphs3D::ShadowQuality)
    shadowStrengthChanged    : typing.ClassVar[Signal] = ... # shadowStrengthChanged()
    tapped                   : typing.ClassVar[Signal] = ... # tapped(QEventPoint,Qt::MouseButton)
    transparencyTechniqueChanged: typing.ClassVar[Signal] = ... # transparencyTechniqueChanged(QtGraphs3D::TransparencyTechnique)
    wheel                    : typing.ClassVar[Signal] = ... # wheel(QWheelEvent*)
    wrapCameraXRotationChanged: typing.ClassVar[Signal] = ... # wrapCameraXRotationChanged(bool)
    wrapCameraYRotationChanged: typing.ClassVar[Signal] = ... # wrapCameraYRotationChanged(bool)
    zoomAtTargetEnabledChanged: typing.ClassVar[Signal] = ... # zoomAtTargetEnabledChanged(bool)
    zoomEnabledChanged       : typing.ClassVar[Signal] = ... # zoomEnabledChanged(bool)
    def activeTheme(self, /) -> PySide6.QtGraphs.QGraphsTheme: ...
    def addCustomItem(self, item: PySide6.QtGraphs.QCustom3DItem, /) -> int: ...
    def addTheme(self, theme: PySide6.QtGraphs.QGraphsTheme, /) -> None: ...
    def ambientLightStrength(self, /) -> float: ...
    def aspectRatio(self, /) -> float: ...
    def cameraPreset(self, /) -> PySide6.QtGraphs.QtGraphs3D.CameraPreset: ...
    def cameraTargetPosition(self, /) -> PySide6.QtGui.QVector3D: ...
    def cameraXRotation(self, /) -> float: ...
    def cameraYRotation(self, /) -> float: ...
    def cameraZoomLevel(self, /) -> float: ...
    def clearSelection(self, /) -> None: ...
    def currentFps(self, /) -> int: ...
    def customItems(self, /) -> typing.List[PySide6.QtGraphs.QCustom3DItem]: ...
    def cutoffMargin(self, /) -> float: ...
    def doPicking(self, point: PySide6.QtCore.QPoint, /) -> None: ...
    def doRayPicking(self, origin: PySide6.QtGui.QVector3D, direction: PySide6.QtGui.QVector3D, /) -> None: ...
    def event(self, event: PySide6.QtCore.QEvent, /) -> bool: ...
    def eventFilter(self, obj: PySide6.QtCore.QObject, event: PySide6.QtCore.QEvent, /) -> bool: ...
    def gridLineType(self, /) -> PySide6.QtGraphs.QtGraphs3D.GridLineType: ...
    def hasSeries(self, series: PySide6.QtGraphs.QAbstract3DSeries, /) -> bool: ...
    def horizontalAspectRatio(self, /) -> float: ...
    def isOrthoProjection(self, /) -> bool: ...
    def isPolar(self, /) -> bool: ...
    def isRotationEnabled(self, /) -> bool: ...
    def isSelectionEnabled(self, /) -> bool: ...
    def isZoomAtTargetEnabled(self, /) -> bool: ...
    def isZoomEnabled(self, /) -> bool: ...
    def labelMargin(self, /) -> float: ...
    def lightColor(self, /) -> PySide6.QtGui.QColor: ...
    def lightStrength(self, /) -> float: ...
    def locale(self, /) -> PySide6.QtCore.QLocale: ...
    def margin(self, /) -> float: ...
    def maxCameraXRotation(self, /) -> float: ...
    def maxCameraYRotation(self, /) -> float: ...
    def maxCameraZoomLevel(self, /) -> float: ...
    def measureFps(self, /) -> bool: ...
    def minCameraXRotation(self, /) -> float: ...
    def minCameraYRotation(self, /) -> float: ...
    def minCameraZoomLevel(self, /) -> float: ...
    def msaaSamples(self, /) -> int: ...
    def optimizationHint(self, /) -> PySide6.QtGraphs.QtGraphs3D.OptimizationHint: ...
    def queriedGraphPosition(self, /) -> PySide6.QtGui.QVector3D: ...
    def radialLabelOffset(self, /) -> float: ...
    def releaseCustomItem(self, item: PySide6.QtGraphs.QCustom3DItem, /) -> None: ...
    def releaseTheme(self, theme: PySide6.QtGraphs.QGraphsTheme, /) -> None: ...
    def removeCustomItem(self, item: PySide6.QtGraphs.QCustom3DItem, /) -> None: ...
    def removeCustomItemAt(self, position: PySide6.QtGui.QVector3D, /) -> None: ...
    def removeCustomItems(self, /) -> None: ...
    def renderToImage(self, /, imageSize: PySide6.QtCore.QSize = ...) -> typing.Tuple[PySide6.QtQuick.QQuickItemGrabResult]: ...
    def scene(self, /) -> PySide6.QtGraphs.Q3DScene: ...
    def selectedAxis(self, /) -> PySide6.QtGraphs.QAbstract3DAxis: ...
    def selectedCustomItem(self, /) -> PySide6.QtGraphs.QCustom3DItem: ...
    def selectedCustomItemIndex(self, /) -> int: ...
    def selectedElement(self, /) -> PySide6.QtGraphs.QtGraphs3D.ElementType: ...
    def selectedLabelIndex(self, /) -> int: ...
    def selectionMode(self, /) -> PySide6.QtGraphs.QtGraphs3D.SelectionFlag: ...
    def setActiveTheme(self, activeTheme: PySide6.QtGraphs.QGraphsTheme, /) -> None: ...
    def setAmbientLightStrength(self, newAmbientLightStrength: float, /) -> None: ...
    def setAspectRatio(self, ratio: float, /) -> None: ...
    def setCameraPosition(self, horizontal: float, vertical: float, /, zoom: float = ...) -> None: ...
    def setCameraPreset(self, preset: PySide6.QtGraphs.QtGraphs3D.CameraPreset, /) -> None: ...
    def setCameraTargetPosition(self, target: PySide6.QtGui.QVector3D, /) -> None: ...
    def setCameraXRotation(self, rotation: float, /) -> None: ...
    def setCameraYRotation(self, rotation: float, /) -> None: ...
    def setCameraZoomLevel(self, level: float, /) -> None: ...
    def setCutoffMargin(self, margin: float, /) -> None: ...
    def setDefaultInputHandler(self, /) -> None: ...
    def setDragButton(self, button: PySide6.QtCore.Qt.MouseButton, /) -> None: ...
    def setGridLineType(self, gridLineType: PySide6.QtGraphs.QtGraphs3D.GridLineType, /) -> None: ...
    def setHorizontalAspectRatio(self, ratio: float, /) -> None: ...
    def setLabelMargin(self, margin: float, /) -> None: ...
    def setLightColor(self, newLightColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setLightStrength(self, newLightStrength: float, /) -> None: ...
    def setLocale(self, locale: PySide6.QtCore.QLocale | PySide6.QtCore.QLocale.Language, /) -> None: ...
    def setMargin(self, margin: float, /) -> None: ...
    def setMaxCameraXRotation(self, rotation: float, /) -> None: ...
    def setMaxCameraYRotation(self, rotation: float, /) -> None: ...
    def setMaxCameraZoomLevel(self, level: float, /) -> None: ...
    def setMeasureFps(self, enable: bool, /) -> None: ...
    def setMinCameraXRotation(self, rotation: float, /) -> None: ...
    def setMinCameraYRotation(self, rotation: float, /) -> None: ...
    def setMinCameraZoomLevel(self, level: float, /) -> None: ...
    def setMsaaSamples(self, samples: int, /) -> None: ...
    def setOptimizationHint(self, hint: PySide6.QtGraphs.QtGraphs3D.OptimizationHint, /) -> None: ...
    def setOrthoProjection(self, enable: bool, /) -> None: ...
    def setPolar(self, enable: bool, /) -> None: ...
    def setRadialLabelOffset(self, offset: float, /) -> None: ...
    def setRotationEnabled(self, enable: bool, /) -> None: ...
    def setSelectionEnabled(self, enable: bool, /) -> None: ...
    def setSelectionMode(self, selectionMode: PySide6.QtGraphs.QtGraphs3D.SelectionFlag, /) -> None: ...
    def setShadowQuality(self, shadowQuality: PySide6.QtGraphs.QtGraphs3D.ShadowQuality, /) -> None: ...
    def setShadowStrength(self, newShadowStrength: float, /) -> None: ...
    def setTransparencyTechnique(self, technique: PySide6.QtGraphs.QtGraphs3D.TransparencyTechnique, /) -> None: ...
    def setWidget(self, widget: PySide6.QtQuickWidgets.QQuickWidget, /) -> None: ...
    def setWrapCameraXRotation(self, wrap: bool, /) -> None: ...
    def setWrapCameraYRotation(self, wrap: bool, /) -> None: ...
    def setZoomAtTargetEnabled(self, enable: bool, /) -> None: ...
    def setZoomEnabled(self, enable: bool, /) -> None: ...
    def shadowQuality(self, /) -> PySide6.QtGraphs.QtGraphs3D.ShadowQuality: ...
    def shadowStrength(self, /) -> float: ...
    def themes(self, /) -> typing.List[PySide6.QtGraphs.QGraphsTheme]: ...
    def transparencyTechnique(self, /) -> PySide6.QtGraphs.QtGraphs3D.TransparencyTechnique: ...
    def unsetDefaultDragHandler(self, /) -> None: ...
    def unsetDefaultInputHandler(self, /) -> None: ...
    def unsetDefaultPinchHandler(self, /) -> None: ...
    def unsetDefaultTapHandler(self, /) -> None: ...
    def unsetDefaultWheelHandler(self, /) -> None: ...
    def widget(self, /) -> PySide6.QtQuickWidgets.QQuickWidget: ...
    def wrapCameraXRotation(self, /) -> bool: ...
    def wrapCameraYRotation(self, /) -> bool: ...


class Q3DScatterWidgetItem(PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem):

    axisXChanged             : typing.ClassVar[Signal] = ... # axisXChanged(QValue3DAxis*)
    axisYChanged             : typing.ClassVar[Signal] = ... # axisYChanged(QValue3DAxis*)
    axisZChanged             : typing.ClassVar[Signal] = ... # axisZChanged(QValue3DAxis*)
    selectedSeriesChanged    : typing.ClassVar[Signal] = ... # selectedSeriesChanged(QScatter3DSeries*)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, axisX: PySide6.QtGraphs.QValue3DAxis | None = ..., axisY: PySide6.QtGraphs.QValue3DAxis | None = ..., axisZ: PySide6.QtGraphs.QValue3DAxis | None = ..., selectedSeries: PySide6.QtGraphs.QScatter3DSeries | None = ...) -> None: ...

    def addAxis(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def addSeries(self, series: PySide6.QtGraphs.QScatter3DSeries, /) -> None: ...
    def axes(self, /) -> typing.List[PySide6.QtGraphs.QValue3DAxis]: ...
    def axisX(self, /) -> PySide6.QtGraphs.QValue3DAxis: ...
    def axisY(self, /) -> PySide6.QtGraphs.QValue3DAxis: ...
    def axisZ(self, /) -> PySide6.QtGraphs.QValue3DAxis: ...
    def event(self, event: PySide6.QtCore.QEvent, /) -> bool: ...
    def releaseAxis(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def removeSeries(self, series: PySide6.QtGraphs.QScatter3DSeries, /) -> None: ...
    def selectedSeries(self, /) -> PySide6.QtGraphs.QScatter3DSeries: ...
    def seriesList(self, /) -> typing.List[PySide6.QtGraphs.QScatter3DSeries]: ...
    def setAxisX(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def setAxisY(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def setAxisZ(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...


class Q3DSurfaceWidgetItem(PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem):

    axisXChanged             : typing.ClassVar[Signal] = ... # axisXChanged(QValue3DAxis*)
    axisYChanged             : typing.ClassVar[Signal] = ... # axisYChanged(QValue3DAxis*)
    axisZChanged             : typing.ClassVar[Signal] = ... # axisZChanged(QValue3DAxis*)
    flipHorizontalGridChanged: typing.ClassVar[Signal] = ... # flipHorizontalGridChanged(bool)
    selectedSeriesChanged    : typing.ClassVar[Signal] = ... # selectedSeriesChanged(QSurface3DSeries*)
    sliceImageChanged        : typing.ClassVar[Signal] = ... # sliceImageChanged(QImage)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, axisX: PySide6.QtGraphs.QValue3DAxis | None = ..., axisY: PySide6.QtGraphs.QValue3DAxis | None = ..., axisZ: PySide6.QtGraphs.QValue3DAxis | None = ..., selectedSeries: PySide6.QtGraphs.QSurface3DSeries | None = ..., flipHorizontalGrid: bool | None = ...) -> None: ...

    def addAxis(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def addSeries(self, series: PySide6.QtGraphs.QSurface3DSeries, /) -> None: ...
    def axes(self, /) -> typing.List[PySide6.QtGraphs.QValue3DAxis]: ...
    def axisX(self, /) -> PySide6.QtGraphs.QValue3DAxis: ...
    def axisY(self, /) -> PySide6.QtGraphs.QValue3DAxis: ...
    def axisZ(self, /) -> PySide6.QtGraphs.QValue3DAxis: ...
    def event(self, event: PySide6.QtCore.QEvent, /) -> bool: ...
    def flipHorizontalGrid(self, /) -> bool: ...
    def releaseAxis(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def removeSeries(self, series: PySide6.QtGraphs.QSurface3DSeries, /) -> None: ...
    def renderSliceToImage(self, index: int, requestedIndex: int, sliceType: PySide6.QtGraphs.QtGraphs3D.SliceCaptureType, /) -> None: ...
    def selectedSeries(self, /) -> PySide6.QtGraphs.QSurface3DSeries: ...
    def seriesList(self, /) -> typing.List[PySide6.QtGraphs.QSurface3DSeries]: ...
    def setAxisX(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def setAxisY(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def setAxisZ(self, axis: PySide6.QtGraphs.QValue3DAxis, /) -> None: ...
    def setFlipHorizontalGrid(self, flip: bool, /) -> None: ...


class QIntList: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtQuickWidgets, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtQuickWidgets`

import PySide6.QtQuickWidgets
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets
import PySide6.QtQml
import PySide6.QtQuick

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal


class QIntList: ...


class QQuickWidget(PySide6.QtWidgets.QWidget):

    sceneGraphError          : typing.ClassVar[Signal] = ... # sceneGraphError(QQuickWindow::SceneGraphError,QString)
    statusChanged            : typing.ClassVar[Signal] = ... # statusChanged(QQuickWidget::Status)

    class ResizeMode(enum.Enum):

        SizeViewToRootObject      = 0x0
        SizeRootObjectToView      = 0x1

    class Status(enum.Enum):

        Null                      = 0x0
        Ready                     = 0x1
        Loading                   = 0x2
        Error                     = 0x3


    @typing.overload
    def __init__(self, engine: PySide6.QtQml.QQmlEngine, parent: PySide6.QtWidgets.QWidget, /, *, resizeMode: PySide6.QtQuickWidgets.QQuickWidget.ResizeMode | None = ..., status: PySide6.QtQuickWidgets.QQuickWidget.Status | None = ..., source: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, uri: str, typeName: str, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, resizeMode: PySide6.QtQuickWidgets.QQuickWidget.ResizeMode | None = ..., status: PySide6.QtQuickWidgets.QQuickWidget.Status | None = ..., source: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, resizeMode: PySide6.QtQuickWidgets.QQuickWidget.ResizeMode | None = ..., status: PySide6.QtQuickWidgets.QQuickWidget.Status | None = ..., source: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, source: PySide6.QtCore.QUrl | str, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, resizeMode: PySide6.QtQuickWidgets.QQuickWidget.ResizeMode | None = ..., status: PySide6.QtQuickWidgets.QQuickWidget.Status | None = ...) -> None: ...

    def dragEnterEvent(self, arg__1: PySide6.QtGui.QDragEnterEvent, /) -> None: ...
    def dragLeaveEvent(self, arg__1: PySide6.QtGui.QDragLeaveEvent, /) -> None: ...
    def dragMoveEvent(self, arg__1: PySide6.QtGui.QDragMoveEvent, /) -> None: ...
    def dropEvent(self, arg__1: PySide6.QtGui.QDropEvent, /) -> None: ...
    def engine(self, /) -> PySide6.QtQml.QQmlEngine: ...
    def errors(self, /) -> typing.List[PySide6.QtQml.QQmlError]: ...
    def event(self, arg__1: PySide6.QtCore.QEvent, /) -> bool: ...
    def focusInEvent(self, event: PySide6.QtGui.QFocusEvent, /) -> None: ...
    def focusNextPrevChild(self, next: bool, /) -> bool: ...
    def focusOutEvent(self, event: PySide6.QtGui.QFocusEvent, /) -> None: ...
    def format(self, /) -> PySide6.QtGui.QSurfaceFormat: ...
    def grabFramebuffer(self, /) -> PySide6.QtGui.QImage: ...
    def hideEvent(self, arg__1: PySide6.QtGui.QHideEvent, /) -> None: ...
    def initialSize(self, /) -> PySide6.QtCore.QSize: ...
    def keyPressEvent(self, arg__1: PySide6.QtGui.QKeyEvent, /) -> None: ...
    def keyReleaseEvent(self, arg__1: PySide6.QtGui.QKeyEvent, /) -> None: ...
    def loadFromModule(self, uri: str, typeName: str, /) -> None: ...
    def mouseDoubleClickEvent(self, arg__1: PySide6.QtGui.QMouseEvent, /) -> None: ...
    def mouseMoveEvent(self, arg__1: PySide6.QtGui.QMouseEvent, /) -> None: ...
    def mousePressEvent(self, arg__1: PySide6.QtGui.QMouseEvent, /) -> None: ...
    def mouseReleaseEvent(self, arg__1: PySide6.QtGui.QMouseEvent, /) -> None: ...
    def paintEvent(self, event: PySide6.QtGui.QPaintEvent, /) -> None: ...
    def quickWindow(self, /) -> PySide6.QtQuick.QQuickWindow: ...
    def resizeEvent(self, arg__1: PySide6.QtGui.QResizeEvent, /) -> None: ...
    def resizeMode(self, /) -> PySide6.QtQuickWidgets.QQuickWidget.ResizeMode: ...
    def rootContext(self, /) -> PySide6.QtQml.QQmlContext: ...
    def rootObject(self, /) -> PySide6.QtQuick.QQuickItem: ...
    def setClearColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setContent(self, url: PySide6.QtCore.QUrl | str, component: PySide6.QtQml.QQmlComponent, item: PySide6.QtCore.QObject, /) -> None: ...
    def setFormat(self, format: PySide6.QtGui.QSurfaceFormat | PySide6.QtGui.QSurfaceFormat.FormatOption, /) -> None: ...
    def setInitialProperties(self, initialProperties: typing.Dict[str, typing.Any], /) -> None: ...
    def setResizeMode(self, arg__1: PySide6.QtQuickWidgets.QQuickWidget.ResizeMode, /) -> None: ...
    def setSource(self, arg__1: PySide6.QtCore.QUrl | str, /) -> None: ...
    def showEvent(self, arg__1: PySide6.QtGui.QShowEvent, /) -> None: ...
    def sizeHint(self, /) -> PySide6.QtCore.QSize: ...
    def source(self, /) -> PySide6.QtCore.QUrl: ...
    def status(self, /) -> PySide6.QtQuickWidgets.QQuickWidget.Status: ...
    def timerEvent(self, arg__1: PySide6.QtCore.QTimerEvent, /) -> None: ...
    def wheelEvent(self, arg__1: PySide6.QtGui.QWheelEvent, /) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtWebEngineQuick, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtWebEngineQuick`

import PySide6.QtWebEngineQuick
import PySide6.QtCore
import PySide6.QtWebEngineCore

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QQuickWebEngineDownloadRequest(PySide6.QtWebEngineCore.QWebEngineDownloadRequest):
    def qt_qmlMarker_uncreatable(self, /) -> None: ...


class QQuickWebEngineProfile(PySide6.QtCore.QObject):

    cachePathChanged         : typing.ClassVar[Signal] = ... # cachePathChanged()
    clearHttpCacheCompleted  : typing.ClassVar[Signal] = ... # clearHttpCacheCompleted()
    downloadFinished         : typing.ClassVar[Signal] = ... # downloadFinished(QQuickWebEngineDownloadRequest*)
    downloadPathChanged      : typing.ClassVar[Signal] = ... # downloadPathChanged()
    downloadRequested        : typing.ClassVar[Signal] = ... # downloadRequested(QQuickWebEngineDownloadRequest*)
    httpAcceptLanguageChanged: typing.ClassVar[Signal] = ... # httpAcceptLanguageChanged()
    httpCacheMaximumSizeChanged: typing.ClassVar[Signal] = ... # httpCacheMaximumSizeChanged()
    httpCacheTypeChanged     : typing.ClassVar[Signal] = ... # httpCacheTypeChanged()
    httpUserAgentChanged     : typing.ClassVar[Signal] = ... # httpUserAgentChanged()
    offTheRecordChanged      : typing.ClassVar[Signal] = ... # offTheRecordChanged()
    persistentCookiesPolicyChanged: typing.ClassVar[Signal] = ... # persistentCookiesPolicyChanged()
    persistentPermissionsPolicyChanged: typing.ClassVar[Signal] = ... # persistentPermissionsPolicyChanged()
    persistentStoragePathChanged: typing.ClassVar[Signal] = ... # persistentStoragePathChanged()
    presentNotification      : typing.ClassVar[Signal] = ... # presentNotification(QWebEngineNotification*)
    pushServiceEnabledChanged: typing.ClassVar[Signal] = ... # pushServiceEnabledChanged()
    spellCheckEnabledChanged : typing.ClassVar[Signal] = ... # spellCheckEnabledChanged()
    spellCheckLanguagesChanged: typing.ClassVar[Signal] = ... # spellCheckLanguagesChanged()
    storageNameChanged       : typing.ClassVar[Signal] = ... # storageNameChanged()

    class HttpCacheType(enum.Enum):

        MemoryHttpCache           = 0x0
        DiskHttpCache             = 0x1
        NoCache                   = 0x2

    class PersistentCookiesPolicy(enum.Enum):

        NoPersistentCookies       = 0x0
        AllowPersistentCookies    = 0x1
        ForcePersistentCookies    = 0x2
        OnlyPersistentCookies     = 0x3

    class PersistentPermissionsPolicy(enum.Enum):

        AskEveryTime              = 0x0
        StoreInMemory             = 0x1
        StoreOnDisk               = 0x2


    @typing.overload
    def __init__(self, storageName: str, /, parent: PySide6.QtCore.QObject | None = ..., *, offTheRecord: bool | None = ..., persistentStoragePath: str | None = ..., cachePath: str | None = ..., httpUserAgent: str | None = ..., httpCacheType: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.HttpCacheType | None = ..., httpAcceptLanguage: str | None = ..., persistentCookiesPolicy: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentCookiesPolicy | None = ..., persistentPermissionsPolicy: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentPermissionsPolicy | None = ..., httpCacheMaximumSize: int | None = ..., spellCheckLanguages: collections.abc.Sequence[str] | None = ..., spellCheckEnabled: bool | None = ..., downloadPath: str | None = ..., isPushServiceEnabled: bool | None = ..., clientHints: PySide6.QtWebEngineCore.QWebEngineClientHints | None = ..., extensionManager: PySide6.QtWebEngineCore.QWebEngineExtensionManager | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, storageName: str | None = ..., offTheRecord: bool | None = ..., persistentStoragePath: str | None = ..., cachePath: str | None = ..., httpUserAgent: str | None = ..., httpCacheType: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.HttpCacheType | None = ..., httpAcceptLanguage: str | None = ..., persistentCookiesPolicy: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentCookiesPolicy | None = ..., persistentPermissionsPolicy: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentPermissionsPolicy | None = ..., httpCacheMaximumSize: int | None = ..., spellCheckLanguages: collections.abc.Sequence[str] | None = ..., spellCheckEnabled: bool | None = ..., downloadPath: str | None = ..., isPushServiceEnabled: bool | None = ..., clientHints: PySide6.QtWebEngineCore.QWebEngineClientHints | None = ..., extensionManager: PySide6.QtWebEngineCore.QWebEngineExtensionManager | None = ...) -> None: ...

    def cachePath(self, /) -> str: ...
    def clearHttpCache(self, /) -> None: ...
    def clientCertificateStore(self, /) -> PySide6.QtWebEngineCore.QWebEngineClientCertificateStore: ...
    def clientHints(self, /) -> PySide6.QtWebEngineCore.QWebEngineClientHints: ...
    def cookieStore(self, /) -> PySide6.QtWebEngineCore.QWebEngineCookieStore: ...
    @staticmethod
    def defaultProfile() -> PySide6.QtWebEngineQuick.QQuickWebEngineProfile: ...
    def downloadPath(self, /) -> str: ...
    def extensionManager(self, /) -> PySide6.QtWebEngineCore.QWebEngineExtensionManager: ...
    def httpAcceptLanguage(self, /) -> str: ...
    def httpCacheMaximumSize(self, /) -> int: ...
    def httpCacheType(self, /) -> PySide6.QtWebEngineQuick.QQuickWebEngineProfile.HttpCacheType: ...
    def httpUserAgent(self, /) -> str: ...
    def installUrlSchemeHandler(self, scheme: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, arg__2: PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler, /) -> None: ...
    def isOffTheRecord(self, /) -> bool: ...
    def isPushServiceEnabled(self, /) -> bool: ...
    def isSpellCheckEnabled(self, /) -> bool: ...
    def listAllPermissions(self, /) -> typing.List[PySide6.QtWebEngineCore.QWebEnginePermission]: ...
    def listPermissionsForOrigin(self, securityOrigin: PySide6.QtCore.QUrl | str, /) -> typing.List[PySide6.QtWebEngineCore.QWebEnginePermission]: ...
    def listPermissionsForPermissionType(self, permissionType: PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType, /) -> typing.List[PySide6.QtWebEngineCore.QWebEnginePermission]: ...
    def persistentCookiesPolicy(self, /) -> PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentCookiesPolicy: ...
    def persistentPermissionsPolicy(self, /) -> PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentPermissionsPolicy: ...
    def persistentStoragePath(self, /) -> str: ...
    def queryPermission(self, securityOrigin: PySide6.QtCore.QUrl | str, permissionType: PySide6.QtWebEngineCore.QWebEnginePermission.PermissionType, /) -> PySide6.QtWebEngineCore.QWebEnginePermission: ...
    def removeAllUrlSchemeHandlers(self, /) -> None: ...
    def removeUrlScheme(self, scheme: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def removeUrlSchemeHandler(self, arg__1: PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler, /) -> None: ...
    def setCachePath(self, path: str, /) -> None: ...
    def setDownloadPath(self, path: str, /) -> None: ...
    def setHttpAcceptLanguage(self, httpAcceptLanguage: str, /) -> None: ...
    def setHttpCacheMaximumSize(self, maxSize: int, /) -> None: ...
    def setHttpCacheType(self, arg__1: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.HttpCacheType, /) -> None: ...
    def setHttpUserAgent(self, userAgent: str, /) -> None: ...
    def setOffTheRecord(self, offTheRecord: bool, /) -> None: ...
    def setPersistentCookiesPolicy(self, arg__1: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentCookiesPolicy, /) -> None: ...
    def setPersistentPermissionsPolicy(self, arg__1: PySide6.QtWebEngineQuick.QQuickWebEngineProfile.PersistentPermissionsPolicy, /) -> None: ...
    def setPersistentStoragePath(self, path: str, /) -> None: ...
    def setPushServiceEnabled(self, enable: bool, /) -> None: ...
    def setSpellCheckEnabled(self, enabled: bool, /) -> None: ...
    def setSpellCheckLanguages(self, languages: collections.abc.Sequence[str], /) -> None: ...
    def setStorageName(self, name: str, /) -> None: ...
    def setUrlRequestInterceptor(self, interceptor: PySide6.QtWebEngineCore.QWebEngineUrlRequestInterceptor, /) -> None: ...
    def spellCheckLanguages(self, /) -> typing.List[str]: ...
    def storageName(self, /) -> str: ...
    def urlSchemeHandler(self, arg__1: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtWebEngineCore.QWebEngineUrlSchemeHandler: ...


class QtWebEngineQuick(Shiboken.Object):
    @staticmethod
    def initialize() -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtHelp, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtHelp`

import PySide6.QtHelp
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QCompressedHelpInfo(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtHelp.QCompressedHelpInfo, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def component(self, /) -> str: ...
    @staticmethod
    def fromCompressedHelpFile(documentationFileName: str, /) -> PySide6.QtHelp.QCompressedHelpInfo: ...
    def isNull(self, /) -> bool: ...
    def namespaceName(self, /) -> str: ...
    def swap(self, other: PySide6.QtHelp.QCompressedHelpInfo, /) -> None: ...
    def version(self, /) -> PySide6.QtCore.QVersionNumber: ...


class QHelpContentItem(Shiboken.Object):
    def child(self, row: int, /) -> PySide6.QtHelp.QHelpContentItem: ...
    def childCount(self, /) -> int: ...
    def childPosition(self, child: PySide6.QtHelp.QHelpContentItem, /) -> int: ...
    def parent(self, /) -> PySide6.QtHelp.QHelpContentItem: ...
    def row(self, /) -> int: ...
    def title(self, /) -> str: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QHelpContentModel(PySide6.QtCore.QAbstractItemModel):

    contentsCreated          : typing.ClassVar[Signal] = ... # contentsCreated()
    contentsCreationStarted  : typing.ClassVar[Signal] = ... # contentsCreationStarted()
    def columnCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...
    def contentItemAt(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtHelp.QHelpContentItem: ...
    def createContents(self, customFilterName: str, /) -> None: ...
    def createContentsForCurrentFilter(self, /) -> None: ...
    def data(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, role: int, /) -> typing.Any: ...
    def index(self, row: int, column: int, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> PySide6.QtCore.QModelIndex: ...
    def isCreatingContents(self, /) -> bool: ...
    @typing.overload
    def parent(self, /) -> PySide6.QtCore.QObject: ...
    @typing.overload
    def parent(self, index: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex, /) -> PySide6.QtCore.QModelIndex: ...
    def rowCount(self, /, parent: PySide6.QtCore.QModelIndex | PySide6.QtCore.QPersistentModelIndex = ...) -> int: ...


class QHelpContentWidget(PySide6.QtWidgets.QTreeView):

    linkActivated            : typing.ClassVar[Signal] = ... # linkActivated(QUrl)
    def indexOf(self, link: PySide6.QtCore.QUrl | str, /) -> PySide6.QtCore.QModelIndex: ...


class QHelpEngine(PySide6.QtHelp.QHelpEngineCore):

    def __init__(self, collectionFile: str, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def contentModel(self, /) -> PySide6.QtHelp.QHelpContentModel: ...
    def contentWidget(self, /) -> PySide6.QtHelp.QHelpContentWidget: ...
    def indexModel(self, /) -> PySide6.QtHelp.QHelpIndexModel: ...
    def indexWidget(self, /) -> PySide6.QtHelp.QHelpIndexWidget: ...
    def searchEngine(self, /) -> PySide6.QtHelp.QHelpSearchEngine: ...


class QHelpEngineCore(PySide6.QtCore.QObject):

    currentFilterChanged     : typing.ClassVar[Signal] = ... # currentFilterChanged(QString)
    readersAboutToBeInvalidated: typing.ClassVar[Signal] = ... # readersAboutToBeInvalidated()
    setupFinished            : typing.ClassVar[Signal] = ... # setupFinished()
    setupStarted             : typing.ClassVar[Signal] = ... # setupStarted()
    warning                  : typing.ClassVar[Signal] = ... # warning(QString)

    def __init__(self, collectionFile: str, /, parent: PySide6.QtCore.QObject | None = ..., *, autoSaveFilter: bool | None = ..., readOnly: bool | None = ..., currentFilter: str | None = ...) -> None: ...

    def addCustomFilter(self, filterName: str, attributes: collections.abc.Sequence[str], /) -> bool: ...
    def autoSaveFilter(self, /) -> bool: ...
    def collectionFile(self, /) -> str: ...
    def copyCollectionFile(self, fileName: str, /) -> bool: ...
    def currentFilter(self, /) -> str: ...
    def customFilters(self, /) -> typing.List[str]: ...
    def customValue(self, key: str, /, defaultValue: typing.Any = ...) -> typing.Any: ...
    def documentationFileName(self, namespaceName: str, /) -> str: ...
    @typing.overload
    def documentsForIdentifier(self, id: str, /) -> typing.List[PySide6.QtHelp.QHelpLink]: ...
    @typing.overload
    def documentsForIdentifier(self, id: str, filterName: str, /) -> typing.List[PySide6.QtHelp.QHelpLink]: ...
    @typing.overload
    def documentsForKeyword(self, keyword: str, /) -> typing.List[PySide6.QtHelp.QHelpLink]: ...
    @typing.overload
    def documentsForKeyword(self, keyword: str, filterName: str, /) -> typing.List[PySide6.QtHelp.QHelpLink]: ...
    def error(self, /) -> str: ...
    def fileData(self, url: PySide6.QtCore.QUrl | str, /) -> PySide6.QtCore.QByteArray: ...
    @typing.overload
    def files(self, namespaceName: str, filterName: str, /, extensionFilter: str = ...) -> typing.List[PySide6.QtCore.QUrl]: ...
    @typing.overload
    def files(self, namespaceName: str, filterAttributes: collections.abc.Sequence[str], /, extensionFilter: str = ...) -> typing.List[PySide6.QtCore.QUrl]: ...
    def filterAttributeSets(self, namespaceName: str, /) -> typing.List[typing.List[str]]: ...
    @typing.overload
    def filterAttributes(self, /) -> typing.List[str]: ...
    @typing.overload
    def filterAttributes(self, filterName: str, /) -> typing.List[str]: ...
    def filterEngine(self, /) -> PySide6.QtHelp.QHelpFilterEngine: ...
    def findFile(self, url: PySide6.QtCore.QUrl | str, /) -> PySide6.QtCore.QUrl: ...
    def isReadOnly(self, /) -> bool: ...
    @staticmethod
    def metaData(documentationFileName: str, name: str, /) -> typing.Any: ...
    @staticmethod
    def namespaceName(documentationFileName: str, /) -> str: ...
    def registerDocumentation(self, documentationFileName: str, /) -> bool: ...
    def registeredDocumentations(self, /) -> typing.List[str]: ...
    def removeCustomFilter(self, filterName: str, /) -> bool: ...
    def removeCustomValue(self, key: str, /) -> bool: ...
    def setAutoSaveFilter(self, save: bool, /) -> None: ...
    def setCollectionFile(self, fileName: str, /) -> None: ...
    def setCurrentFilter(self, filterName: str, /) -> None: ...
    def setCustomValue(self, key: str, value: typing.Any, /) -> bool: ...
    def setReadOnly(self, enable: bool, /) -> None: ...
    def setUsesFilterEngine(self, uses: bool, /) -> None: ...
    def setupData(self, /) -> bool: ...
    def unregisterDocumentation(self, namespaceName: str, /) -> bool: ...
    def usesFilterEngine(self, /) -> bool: ...


class QHelpFilterData(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtHelp.QHelpFilterData, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtHelp.QHelpFilterData, /) -> bool: ...
    def components(self, /) -> typing.List[str]: ...
    def setComponents(self, components: collections.abc.Sequence[str], /) -> None: ...
    def setVersions(self, versions: collections.abc.Sequence[PySide6.QtCore.QVersionNumber], /) -> None: ...
    def swap(self, other: PySide6.QtHelp.QHelpFilterData, /) -> None: ...
    def versions(self, /) -> typing.List[PySide6.QtCore.QVersionNumber]: ...


class QHelpFilterEngine(PySide6.QtCore.QObject):

    filterActivated          : typing.ClassVar[Signal] = ... # filterActivated(QString)

    def __init__(self, helpEngine: PySide6.QtHelp.QHelpEngineCore, /) -> None: ...

    def activeFilter(self, /) -> str: ...
    def availableComponents(self, /) -> typing.List[str]: ...
    def availableVersions(self, /) -> typing.List[PySide6.QtCore.QVersionNumber]: ...
    def filterData(self, filterName: str, /) -> PySide6.QtHelp.QHelpFilterData: ...
    def filters(self, /) -> typing.List[str]: ...
    @typing.overload
    def indices(self, /) -> typing.List[str]: ...
    @typing.overload
    def indices(self, filterName: str, /) -> typing.List[str]: ...
    def namespaceToComponent(self, /) -> typing.Dict[str, str]: ...
    def namespaceToVersion(self, /) -> typing.Dict[str, PySide6.QtCore.QVersionNumber]: ...
    def namespacesForFilter(self, filterName: str, /) -> typing.List[str]: ...
    def removeFilter(self, filterName: str, /) -> bool: ...
    def setActiveFilter(self, filterName: str, /) -> bool: ...
    def setFilterData(self, filterName: str, filterData: PySide6.QtHelp.QHelpFilterData, /) -> bool: ...


class QHelpFilterSettingsWidget(PySide6.QtWidgets.QWidget):

    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ...) -> None: ...

    def applySettings(self, filterEngine: PySide6.QtHelp.QHelpFilterEngine, /) -> bool: ...
    def readSettings(self, filterEngine: PySide6.QtHelp.QHelpFilterEngine, /) -> None: ...
    def setAvailableComponents(self, components: collections.abc.Sequence[str], /) -> None: ...
    def setAvailableVersions(self, versions: collections.abc.Sequence[PySide6.QtCore.QVersionNumber], /) -> None: ...


class QHelpGlobal(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QHelpGlobal: PySide6.QtHelp.QHelpGlobal, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    @staticmethod
    def documentTitle(content: str, /) -> str: ...
    @staticmethod
    def uniquifyConnectionName(name: str, pointer: int, /) -> str: ...


class QHelpIndexModel(PySide6.QtCore.QStringListModel):

    indexCreated             : typing.ClassVar[Signal] = ... # indexCreated()
    indexCreationStarted     : typing.ClassVar[Signal] = ... # indexCreationStarted()
    def createIndex(self, customFilterName: str, /) -> None: ...
    def createIndexForCurrentFilter(self, /) -> None: ...
    def filter(self, filter: str, /, wildcard: str = ...) -> PySide6.QtCore.QModelIndex: ...
    def helpEngine(self, /) -> PySide6.QtHelp.QHelpEngineCore: ...
    def isCreatingIndex(self, /) -> bool: ...


class QHelpIndexWidget(PySide6.QtWidgets.QListView):

    documentActivated        : typing.ClassVar[Signal] = ... # documentActivated(QHelpLink,QString)
    documentsActivated       : typing.ClassVar[Signal] = ... # documentsActivated(QList<QHelpLink>,QString)
    linkActivated            : typing.ClassVar[Signal] = ... # linkActivated(QUrl,QString)
    linksActivated           : typing.ClassVar[Signal] = ... # linksActivated(QMultiMap<QString,QUrl>,QString)
    def activateCurrentItem(self, /) -> None: ...
    def filterIndices(self, filter: str, /, wildcard: str = ...) -> None: ...


class QHelpLink(Shiboken.Object):

    title                     = ...  # type: str
    url                       = ...  # type: PySide6.QtCore.QUrl

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QHelpLink: PySide6.QtHelp.QHelpLink, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...


class QHelpSearchEngine(PySide6.QtCore.QObject):

    indexingFinished         : typing.ClassVar[Signal] = ... # indexingFinished()
    indexingStarted          : typing.ClassVar[Signal] = ... # indexingStarted()
    searchingFinished        : typing.ClassVar[Signal] = ... # searchingFinished(int)
    searchingStarted         : typing.ClassVar[Signal] = ... # searchingStarted()

    def __init__(self, helpEngine: PySide6.QtHelp.QHelpEngineCore, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def cancelIndexing(self, /) -> None: ...
    def cancelSearching(self, /) -> None: ...
    def hitCount(self, /) -> int: ...
    def hits(self, start: int, end: int, /) -> typing.List[typing.Tuple[str, str]]: ...
    def hitsCount(self, /) -> int: ...
    def query(self, /) -> typing.List[PySide6.QtHelp.QHelpSearchQuery]: ...
    def queryWidget(self, /) -> PySide6.QtHelp.QHelpSearchQueryWidget: ...
    def reindexDocumentation(self, /) -> None: ...
    def resultWidget(self, /) -> PySide6.QtHelp.QHelpSearchResultWidget: ...
    def scheduleIndexDocumentation(self, /) -> None: ...
    @typing.overload
    def search(self, searchInput: str, /) -> None: ...
    @typing.overload
    def search(self, queryList: collections.abc.Sequence[PySide6.QtHelp.QHelpSearchQuery], /) -> None: ...
    def searchInput(self, /) -> str: ...
    def searchResultCount(self, /) -> int: ...
    def searchResults(self, start: int, end: int, /) -> typing.List[PySide6.QtHelp.QHelpSearchResult]: ...


class QHelpSearchEngineCore(PySide6.QtCore.QObject):

    indexingFinished         : typing.ClassVar[Signal] = ... # indexingFinished()
    indexingStarted          : typing.ClassVar[Signal] = ... # indexingStarted()
    searchingFinished        : typing.ClassVar[Signal] = ... # searchingFinished()
    searchingStarted         : typing.ClassVar[Signal] = ... # searchingStarted()

    def __init__(self, helpEngine: PySide6.QtHelp.QHelpEngineCore, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def cancelIndexing(self, /) -> None: ...
    def cancelSearching(self, /) -> None: ...
    def reindexDocumentation(self, /) -> None: ...
    def scheduleIndexDocumentation(self, /) -> None: ...
    def search(self, searchInput: str, /) -> None: ...
    def searchInput(self, /) -> str: ...
    def searchResultCount(self, /) -> int: ...
    def searchResults(self, start: int, end: int, /) -> typing.List[PySide6.QtHelp.QHelpSearchResult]: ...


class QHelpSearchQuery(Shiboken.Object):

    fieldName                 = ...  # type: PySide6.QtHelp.QHelpSearchQuery.FieldName
    wordList                  = ...  # type: typing.List[str]

    class FieldName(enum.Enum):

        DEFAULT                   = 0x0
        FUZZY                     = 0x1
        WITHOUT                   = 0x2
        PHRASE                    = 0x3
        ALL                       = 0x4
        ATLEAST                   = 0x5


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, field: PySide6.QtHelp.QHelpSearchQuery.FieldName, wordList_: collections.abc.Sequence[str], /) -> None: ...
    @typing.overload
    def __init__(self, QHelpSearchQuery: PySide6.QtHelp.QHelpSearchQuery, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...


class QHelpSearchQueryWidget(PySide6.QtWidgets.QWidget):

    search                   : typing.ClassVar[Signal] = ... # search()

    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ...) -> None: ...

    def changeEvent(self, event: PySide6.QtCore.QEvent, /) -> None: ...
    def collapseExtendedSearch(self, /) -> None: ...
    def expandExtendedSearch(self, /) -> None: ...
    def focusInEvent(self, focusEvent: PySide6.QtGui.QFocusEvent, /) -> None: ...
    def isCompactMode(self, /) -> bool: ...
    def query(self, /) -> typing.List[PySide6.QtHelp.QHelpSearchQuery]: ...
    def searchInput(self, /) -> str: ...
    def setCompactMode(self, on: bool, /) -> None: ...
    def setQuery(self, queryList: collections.abc.Sequence[PySide6.QtHelp.QHelpSearchQuery], /) -> None: ...
    def setSearchInput(self, searchInput: str, /) -> None: ...


class QHelpSearchResult(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtHelp.QHelpSearchResult, /) -> None: ...
    @typing.overload
    def __init__(self, url: PySide6.QtCore.QUrl | str, title: str, snippet: str, /) -> None: ...

    def snippet(self, /) -> str: ...
    def title(self, /) -> str: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QHelpSearchResultWidget(PySide6.QtWidgets.QWidget):

    requestShowLink          : typing.ClassVar[Signal] = ... # requestShowLink(QUrl)
    def changeEvent(self, event: PySide6.QtCore.QEvent, /) -> None: ...
    def linkAt(self, point: PySide6.QtCore.QPoint, /) -> PySide6.QtCore.QUrl: ...


class QIntList: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof
